#include <zephyr/zephyr.h>

#include <os_mgmt/os_mgmt.h>
#include <img_mgmt/img_mgmt.h>
#include <bluetooth/bluetooth.h>
#include <mgmt/mcumgr/smp_bt.h>
#include <settings/settings.h>

#include <logging/log.h>
LOG_MODULE_REGISTER(hello_world);

#define DEVICE_NAME     CONFIG_BT_DEVICE_NAME
#define DEVICE_NAME_LEN (sizeof(DEVICE_NAME) - 1)

static const struct bt_data ad[] = {
	BT_DATA_BYTES(BT_DATA_FLAGS, (BT_LE_AD_GENERAL | BT_LE_AD_NO_BREDR)),
	BT_DATA(BT_DATA_NAME_COMPLETE, DEVICE_NAME, DEVICE_NAME_LEN),
};

static const struct bt_data sd[] = {
    BT_DATA(BT_DATA_NAME_COMPLETE, DEVICE_NAME, DEVICE_NAME_LEN),
};

void main(void)
{
	LOG_INF("Hello World! %s\n", CONFIG_BOARD);

	int err = bt_enable(NULL);
	LOG_INF("Bluetooth enabled (%d)", err);
	err = settings_subsys_init();
	LOG_INF("Settings subsys initialized (%d)", err);
    err = settings_load();
	LOG_INF("Settings loaded (%d)", err);

	os_mgmt_register_group();
	img_mgmt_register_group();
	smp_bt_register();

	struct bt_le_adv_param *adv_param = BT_LE_ADV_PARAM(
	BT_LE_ADV_OPT_CONNECTABLE, BT_GAP_ADV_FAST_INT_MIN_2, BT_GAP_ADV_FAST_INT_MAX_2, NULL);

    err = bt_le_adv_start(adv_param, ad, ARRAY_SIZE(ad), sd, ARRAY_SIZE(sd));
	LOG_INF("Advertising started (%d)", err);
}
